to_pascal_case

Function to_pascal_case 

pub fn to_pascal_case<T>(input: &T) -> Cow<'_, [u8]>
where T: AsRef<[u8]> + ?Sized,
Converts input bytes to canonical ASCII PascalCase.

The function returns a borrowed slice when the input is already canonical, otherwise it returns an owned normalized buffer.